summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeparameter.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/codeparameter.cpp
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/codeparameter.cpp')
-rw-r--r--umbrello/umbrello/codeparameter.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/umbrello/umbrello/codeparameter.cpp b/umbrello/umbrello/codeparameter.cpp
index 5ee7345c..1ca714fc 100644
--- a/umbrello/umbrello/codeparameter.cpp
+++ b/umbrello/umbrello/codeparameter.cpp
@@ -33,10 +33,10 @@
// Constructors/Destructors
//
-CodeParameter::CodeParameter ( ClassifierCodeDocument * parentDoc, UMLObject * parentObject )
- : TQObject ( (TQObject*) parentObject, "ACodeParam")
+CodeParameter::CodeParameter ( ClassifierCodeDocument * tqparentDoc, UMLObject * tqparentObject )
+ : TQObject ( (TQObject*) tqparentObject, "ACodeParam")
{
- initFields( parentDoc, parentObject );
+ initFields( tqparentDoc, tqparentObject );
}
CodeParameter::~CodeParameter ( ) { }
@@ -50,15 +50,15 @@ CodeParameter::~CodeParameter ( ) { }
//
/**
* Utility method to get the value of parent object abstract value
* @return the value of parent object abstrtact
*/
bool CodeParameter::getAbstract ( ) {
return m_parentObject->getAbstract();
}
/**
* Utility method to get the value of parent object static
* Whether or not this is static.
* @return the value of static
*/
@@ -67,7 +67,7 @@ bool CodeParameter::getStatic ( ) {
}
/**
* Utility method to get the value of parent object name
* The name of this code parameter.
* @return the value
*/
@@ -76,7 +76,7 @@ TQString CodeParameter::getName ( ) const {
}
/**
* Utility method to get the value of parent object type.
* the typeName of this parameters (e.g. boolean, int, etc or perhaps Class name of
* an object)
* @return the value of type
@@ -87,9 +87,9 @@ TQString CodeParameter::getTypeName ( ) {
}
/**
* Utility method to get the value of parent object scope.
* The visibility of this code parameter.
* @return the value of parent object scope
*/
Uml::Visibility CodeParameter::getVisibility ( ) const {
return m_parentObject->getVisibility();
@@ -139,7 +139,7 @@ UMLObject * CodeParameter::getParentObject ( ) {
return m_parentObject;
}
// need to get the ID of the parent object
// this is kind of broken for UMLRoles.
TQString CodeParameter::getID () {
UMLRole * role = dynamic_cast<UMLRole*>(m_parentObject);
@@ -162,7 +162,7 @@ void CodeParameter::setAttributesOnNode ( TQDomDocument & doc, TQDomElement & bl
// set local attributes
- blockElement.setAttribute("parent_id",getID());
+ blockElement.setAttribute("tqparent_id",getID());
// setting ID's takes special treatment
// as UMLRoles arent properly stored in the XMI right now.
@@ -187,8 +187,8 @@ void CodeParameter::setAttributesOnNode ( TQDomDocument & doc, TQDomElement & bl
*/
void CodeParameter::setAttributesFromNode ( TQDomElement & root) {
- // set local attributes, parent object first
- TQString idStr = root.attribute("parent_id","-1");
+ // set local attributes, tqparent object first
+ TQString idStr = root.attribute("tqparent_id","-1");
Uml::IDType id = STR2ID(idStr);
// always disconnect
@@ -202,7 +202,7 @@ void CodeParameter::setAttributesFromNode ( TQDomElement & root) {
// FIX..one day.
// Ugh. This is UGLY, but we have to do it this way because UMLRoles
// don't go into the document list of UMLobjects, and have the same
// ID as their parent UMLAssociations. So..the drill is then special
// for Associations..in that case we need to find out which role will
// serve as the parameter here. The REAL fix, of course, would be to
// treat UMLRoles on a more even footing, but im not sure how that change
@@ -230,7 +230,7 @@ void CodeParameter::setAttributesFromNode ( TQDomElement & root) {
initFields ( m_parentDocument, obj); // just the regular approach
} else
- kError() << "Cant load CodeParam: parentUMLObject w/id:"
+ kError() << "Cant load CodeParam: tqparentUMLObject w/id:"
<< ID2STR(id) << " not found, corrupt save file?" << endl;
// other attribs now
@@ -262,7 +262,7 @@ void CodeParameter::setAttributesFromNode ( TQDomElement & root) {
/**
* create the string representation of this code parameter.
- * @return QString
+ * @return TQString
*/
void CodeParameter::syncToParent( ) {
@@ -50,15 +50,15 @@ CodeParameter::~CodeParameter ( ) { }
//
/**
- * Utility method to get the value of parent object abstract value
- * @return the value of parent object abstrtact
+ * Utility method to get the value of tqparent object abstract value
+ * @return the value of tqparent object abstrtact
*/
bool CodeParameter::getAbstract ( ) {
@@ -50,15 +50,15 @@ CodeParameter::~CodeParameter ( ) { }
}
/**
- * Utility method to get the value of parent object static
+ * Utility method to get the value of tqparent object static
* Whether or not this is static.
* @return the value of static
@@ -67,7 +67,7 @@ bool CodeParameter::getStatic ( ) {
}
/**
- * Utility method to get the value of parent object name
+ * Utility method to get the value of tqparent object name
* The name of this code parameter.
* @return the value
@@ -76,7 +76,7 @@ TQString CodeParameter::getName ( ) const {
}
/**
- * Utility method to get the value of parent object type.
+ * Utility method to get the value of tqparent object type.
* the typeName of this parameters (e.g. boolean, int, etc or perhaps Class name of
* an object)
@@ -87,9 +87,9 @@ TQString CodeParameter::getTypeName ( ) {
}
/**
- * Utility method to get the value of parent object scope.
+ * Utility method to get the value of tqparent object scope.
* The visibility of this code parameter.
@@ -87,9 +87,9 @@ TQString CodeParameter::getTypeName ( ) {
* The visibility of this code parameter.
- * @return the value of parent object scope
+ * @return the value of tqparent object scope
*/
Uml::Visibility CodeParameter::getVisibility ( ) const {
@@ -139,7 +139,7 @@ UMLObject * CodeParameter::getParentObject ( ) {
return m_parentObject;
}
-// need to get the ID of the parent object
+// need to get the ID of the tqparent object
// this is kind of broken for UMLRoles.
TQString CodeParameter::getID () {
@@ -202,7 +202,7 @@ void CodeParameter::setAttributesFromNode ( TQDomElement & root) {
// Ugh. This is UGLY, but we have to do it this way because UMLRoles
// don't go into the document list of UMLobjects, and have the same
- // ID as their parent UMLAssociations. So..the drill is then special
+ // ID as their tqparent UMLAssociations. So..the drill is then special
// for Associations..in that case we need to find out which role will
// serve as the parameter here. The REAL fix, of course, would be to